# GENERATED FILE - DO NOT EDIT
BUILDS = {'Darwin': {'sha256': 'b1efd966b47aeec100d197fa718981ff660e6f72ce5b4b06fd718258e4e3cbfd',
            'url': 'http://s3-us-west-2.amazonaws.com/ai2-thor/builds/thor-201712201205-OSXIntel64.zip'},
 'Linux': {'sha256': '2a48478762d15ea2dc5345639448142f357dcafb98f898c9fee33b8798c992ed',
           'url': 'http://s3-us-west-2.amazonaws.com/ai2-thor/builds/thor-201712201205-Linux64.zip'}}